find_stata <- function(message=TRUE) {
  stataexe <- ""
  if (.Platform$OS.type == "windows"){
# if (message) packageStartupMessage("OS : Windows")
#  stataexe <- NULL
  for (d in c("C:/Program Files","C:/Program Files (x86)")) {
    if (stataexe=="" & dir.exists(d)) {
# if (message) packageStartupMessage("trying : ", d)
      for (v in seq(19,11,-1)) {
        for (dirstub in c("Stata", "StataNow", "StataNow19")){
          dv <- paste(d, paste0(dirstub,v), sep="/")
          if (dir.exists(dv)) {
# if (message) packageStartupMessage("trying : ", dv)
            for (f in c("Stata", "StataIC", "StataSE", "StataMP", "StataBE",
                        "Stata-64", "StataIC-64", "StataSE-64", "StataMP-64", "StataBE-64")) {
              dvf <- paste(paste(dv, f, sep="/"), "exe", sep=".")
              if (file.exists(dvf)) {
# if (message) packageStartupMessage("trying : ", dvf)
                stataexe <- dvf
                if (message) packageStartupMessage("Stata found at ", stataexe)
              }
              if (stataexe != "") break
              }
          }
        }
       if (stataexe != "") break
      }
    }
    if (stataexe != "") break
}
  } else if (Sys.info()["sysname"]=="Darwin") {
#    stataexe <- NULL
    dvstub <- c("/Applications/StataNow", "/Applications/Stata")
    for (dv in dvstub) {
    if (dir.exists(dv)) {
      for (f in c("Stata", "StataSE", "StataMP", "StataIC", "StataBE")) {
        dvf <- paste(paste(paste(dv, f, sep="/"), "app", sep="."), "Contents/MacOS", f, sep="/")
        if (file.exists(dvf)) {
          stataexe <- dvf
          if (message) packageStartupMessage("Stata found at ", stataexe)
        }
        if (stataexe != "") break
      }
    }
    }
  } else if (.Platform$OS.type == "unix") {
#      stataexe <- NULL
    for (f in c("stata-mp", "stata-se", "stata", "stata-ic")) {
      stataexe <- Sys.which(f)[[f]]
      if (stataexe != '') {
        if (message) packageStartupMessage("Stata found at ", stataexe)
      }
      else
        for (d in c("/software/stata", "/usr/local/sbin", "/usr/local/bin", "/usr/sbin",
                    "/usr/local/statanow19", "/usr/local/stata19", "/usr/local/stata", "/usr/local/stata18", "/usr/local/stata17", "/usr/local/stata16",
                    "/usr/local/stata15")) {
          df <- paste(d, f, sep="/")
          if (file.exists(df)) {
            stataexe <- df
            if (message) packageStartupMessage("Stata found at ", stataexe)
          }
          if (stataexe != "") break
        }
      if (stataexe != "") break
    }
  } else {
    message("Unrecognized operating system.")
  }
  if (stataexe!="") {
    knitr::opts_chunk$set(engine.path=list(stata=stataexe))
  } else {
    packageStartupMessage("No Stata executable found.")
  }
  return(stataexe)
}

